Release Notes
=============

v0.8 on 18 July 2011
--------------------
This is the first release.

Future releases
---------------
v1.0
----
 - Option to have one-degree-of-freedom joints at the ankles and wrists.
 - Fix 2D plotting.
 - Remove dependence on the python-visual library.
